import { existsSync } from 'fs';
import { dirname, resolve } from 'path';
import { SyntaxKind, isExportDeclaration, isImportDeclaration, isStringLiteral, } from 'typescript';
export function shouldMutateModuleSpecifier(source, node, debug, program) {
    if (!isImportDeclaration(node) && !isExportDeclaration(node)) {
        // not "import .. from" or "export .. from"
        return false;
    }
    const moduleSpecifier = node.moduleSpecifier;
    if (!moduleSpecifier || !(moduleSpecifier.kind === SyntaxKind.StringLiteral || isStringLiteral(moduleSpecifier))) {
        debug('  ! syntax error: ', node.getText());
        return false;
    }
    if (moduleSpecifier.text.startsWith('./') || moduleSpecifier.text.startsWith('../')) {
        const dir = dirname(source);
        for (const ext of ['.ts', '.tsx']) {
            const fp = resolve(dir, moduleSpecifier.text + ext);
            if (program) {
                if (program.getSourceFile(fp)) {
                    return true;
                }
                else {
                    debug('  ! imported file <%s> not in program');
                }
            }
            else {
                if (existsSync(fp)) {
                    return true;
                }
                else {
                    debug('  ! imported file <%s> not exists');
                }
            }
        }
        debug(' ??? ', dir, moduleSpecifier.text);
        return false;
    }
    else {
        // TODO: handle paths mapping (absolute to tsconfig.json)
        debug('absolute import: %s', node.moduleSpecifier?.getText());
        return false;
    }
}
//# sourceMappingURL=shouldMutateModuleSpecifier.js.map